==> jc-1.4.0.tar.gz: soot/coffi/Instruction__5fFaload.h <==
// class soot.coffi.Instruction_Faload

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class b569d3cf8762c695 soot_coffi_Instruction
// @dep_class b90c8e0892f47f67 soot_coffi_Instruction__5fFaload
// @dep_class 741c2648db62361c soot_coffi_Instruction__5fnoargs

// header file dependencies
// @dep_header soot_coffi_Instruction__5fnoargs

#include "soot/coffi/Instruction__5fnoargs.h"

#ifndef _JC_soot_coffi_Instruction__5fFaload_H_
#define _JC_soot_coffi_Instruction__5fFaload_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_coffi_Instruction__5fFaload$sub_refs	_jc_soot_coffi_Instruction__5fFaload$sub_refs;
typedef struct _jc_soot_coffi_Instruction__5fFaload$sub_nonrefs	_jc_soot_coffi_Instruction__5fFaload$sub_nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fFaload$refs	_jc_soot_coffi_Instruction__5fFaload$refs;
typedef struct _jc_soot_coffi_Instruction__5fFaload$nonrefs	_jc_soot_coffi_Instruction__5fFaload$nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fFaload$object	_jc_soot_coffi_Instruction__5fFaload$object;

typedef const struct _jc_soot_coffi_Instruction__5fFaload$vmethods	_jc_soot_coffi_Instruction__5fFaload$vmethods;
typedef const struct _jc_soot_coffi_Instruction__5fFaload$vtable	_jc_soot_coffi_Instruction__5fFaload$vtable;
typedef const struct _jc_soot_coffi_Instruction__5fFaload$vtype	_jc_soot_coffi_Instruction__5fFaload$vtype;

// Constructors
extern void _jc_soot_coffi_Instruction__5fFaload$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_Instruction__5fFaload$object *);

// Virtual methods structure
struct _jc_soot_coffi_Instruction__5fFaload$vmethods {
};

// Vtable
struct _jc_soot_coffi_Instruction__5fFaload$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_Instruction$vmethods	soot_coffi_Instruction;
	_jc_soot_coffi_Instruction__5fnoargs$vmethods	soot_coffi_Instruction__5fnoargs;
	_jc_soot_coffi_Instruction__5fFaload$vmethods	soot_coffi_Instruction__5fFaload;
};

// Vtype
struct _jc_soot_coffi_Instruction__5fFaload$vtype {
	_jc_type			type;
	_jc_soot_coffi_Instruction__5fFaload$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fFaload$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fFaload$refs {
    _jc_soot_coffi_Instruction__5fFaload$sub_refs	soot_coffi_Instruction__5fFaload;
    _jc_soot_coffi_Instruction__5fnoargs$sub_refs	soot_coffi_Instruction__5fnoargs;
    _jc_soot_coffi_Instruction$sub_refs	soot_coffi_Instruction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fFaload$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fFaload$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_Instruction$sub_nonrefs	soot_coffi_Instruction;
    _jc_soot_coffi_Instruction__5fnoargs$sub_nonrefs	soot_coffi_Instruction__5fnoargs;
    _jc_soot_coffi_Instruction__5fFaload$sub_nonrefs	soot_coffi_Instruction__5fFaload;
};

// Object instance structure
struct _jc_soot_coffi_Instruction__5fFaload$object {
	_jc_soot_coffi_Instruction__5fFaload$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Instruction__5fFaload$vtype	*vtype;
	_jc_soot_coffi_Instruction__5fFaload$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Instruction__5fFaload$vtype _jc_soot_coffi_Instruction__5fFaload$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Instruction__5fFaload, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Instruction__5fFaload$class_object;

#endif	/* _JC_soot_coffi_Instruction__5fFaload_H_ */

==> jc-1.4.6.tar.gz: soot/coffi/Instruction__5fFaload.h <==
// class soot.coffi.Instruction_Faload

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b569d3cf8762c695 soot_coffi_Instruction
// @dep_class b90c8e0892f47f67 soot_coffi_Instruction__5fFaload
// @dep_class 741c2648db62361c soot_coffi_Instruction__5fnoargs

// header file dependencies
// @dep_header soot_coffi_Instruction__5fnoargs

#include "soot/coffi/Instruction__5fnoargs.h"

#ifndef _JC_soot_coffi_Instruction__5fFaload_H_
#define _JC_soot_coffi_Instruction__5fFaload_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_coffi_Instruction__5fFaload$sub_refs	_jc_soot_coffi_Instruction__5fFaload$sub_refs;
typedef struct _jc_soot_coffi_Instruction__5fFaload$sub_nonrefs	_jc_soot_coffi_Instruction__5fFaload$sub_nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fFaload$refs	_jc_soot_coffi_Instruction__5fFaload$refs;
typedef struct _jc_soot_coffi_Instruction__5fFaload$nonrefs	_jc_soot_coffi_Instruction__5fFaload$nonrefs;
typedef struct _jc_soot_coffi_Instruction__5fFaload$object	_jc_soot_coffi_Instruction__5fFaload$object;

typedef const struct _jc_soot_coffi_Instruction__5fFaload$vmethods	_jc_soot_coffi_Instruction__5fFaload$vmethods;
typedef const struct _jc_soot_coffi_Instruction__5fFaload$vtable	_jc_soot_coffi_Instruction__5fFaload$vtable;
typedef const struct _jc_soot_coffi_Instruction__5fFaload$vtype	_jc_soot_coffi_Instruction__5fFaload$vtype;

// Constructors
extern void _jc_soot_coffi_Instruction__5fFaload$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_coffi_Instruction__5fFaload$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_coffi_Instruction__5fFaload$vmethods {
};

// Vtable
struct _jc_soot_coffi_Instruction__5fFaload$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_coffi_Instruction$vmethods	soot_coffi_Instruction;
	_jc_soot_coffi_Instruction__5fnoargs$vmethods	soot_coffi_Instruction__5fnoargs;
	_jc_soot_coffi_Instruction__5fFaload$vmethods	soot_coffi_Instruction__5fFaload;
};

// Vtype
struct _jc_soot_coffi_Instruction__5fFaload$vtype {
	_jc_type			type;
	_jc_soot_coffi_Instruction__5fFaload$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fFaload$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fFaload$refs {
    _jc_soot_coffi_Instruction__5fFaload$sub_refs	soot_coffi_Instruction__5fFaload;
    _jc_soot_coffi_Instruction__5fnoargs$sub_refs	soot_coffi_Instruction__5fnoargs;
    _jc_soot_coffi_Instruction$sub_refs	soot_coffi_Instruction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_coffi_Instruction__5fFaload$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_coffi_Instruction__5fFaload$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_coffi_Instruction$sub_nonrefs	soot_coffi_Instruction;
    _jc_soot_coffi_Instruction__5fnoargs$sub_nonrefs	soot_coffi_Instruction__5fnoargs;
    _jc_soot_coffi_Instruction__5fFaload$sub_nonrefs	soot_coffi_Instruction__5fFaload;
};

// Object instance structure
struct _jc_soot_coffi_Instruction__5fFaload$object {
	_jc_soot_coffi_Instruction__5fFaload$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_coffi_Instruction__5fFaload$vtype	*vtype;
	_jc_soot_coffi_Instruction__5fFaload$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_coffi_Instruction__5fFaload$vtype _jc_soot_coffi_Instruction__5fFaload$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_coffi_Instruction__5fFaload, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_coffi_Instruction__5fFaload$class_object;

#endif	/* _JC_soot_coffi_Instruction__5fFaload_H_ */
